@@ -431,90 +431,6 @@ class GlobalPositionComponent
     }
 }
 
-class MapComponent
-{
-    static get annotations()
-    {
-        return [new ng.core.Component({
-            selector: 'rospilotmap',
-            template: '<div id="map" style="height:400px;width:500px;"></div>'
-        })];
-    }
-
-    static get parameters()
-    {
-        return [Copter];
-    }
-
-    constructor(copter)
-    {
-        this.copter = copter;
-    }
-
-    ngOnInit()
-    {
-        var map = L.map('map', {
-            crs: L.CRS.EPSG3857,
-            center: {lat: 37.77, lng: -122.49},
-            zoom: 10,
-            contextmenu: true,
-            contextmenuWidth: 150,
-            contextmenuItems: [
-                {
-                    text: 'Set Waypoint',
-                    callback: e => {
-                        this.copter.setWaypoint(e.latlng.lat, e.latlng.lng);
-                    },
-                }
-            ],
-        });
-        var server_name = window.location.hostname;
-        var mapnik_url = 'http://' + server_name + ':8086/ex/{z}/{x}/{y}.png';
-
-        L.tileLayer(mapnik_url, {
-            maxZoom: 18,
-        }).addTo(map);
-
-        var copterIcon = L.AwesomeMarkers.icon({
-            prefix: 'fa',
-            icon: 'plane',
-            markerColor: 'red'
-        });
-
-        this.marker = L.marker([37.77, -122.49], {
-            title: 'Multicopter',
-            icon: copterIcon
-        }).addTo(map);
-
-        var waypointIcon = L.AwesomeMarkers.icon({
-            prefix: 'fa',
-            icon: 'flag',
-            markerColor: 'green'
-        });
-
-        this.waypoint_marker = L.marker([37.77, -122.49], {
-            title: 'Waypoint',
-            icon: waypointIcon
-        }).addTo(map);
-
-        this.waypoint_subscription = this.copter.getWaypoint().subscribe((waypoint) => {
-            var lat = waypoint.latitude;
-            var lng = waypoint.longitude;
-            this.waypoint_marker.setLatLng([lat, lng]);
-        });
-
-        this.gps_subscription = this.copter.getGlobalPosition().subscribe((position) => {
-            this.marker.setLatLng([position.latitude, position.longitude]);
-        });
-    }
-
-    ngOnDestroy()
-    {
-        this.waypoint_subscription.unsubscribe();
-        this.gps_subscription.unsubscribe();
-    }
-}
-
 class ComeHereComponent
 {
     static get annotations()
